# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: programme_startrun.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import programme_resource_pb2 as programme__resource__pb2
from ..pb2 import terminaltype_pb2 as terminaltype__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='programme_startrun.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\035com.ubtechinc.alpha.programme',
    serialized_pb=b'\n\x18programme_startrun.proto\x1a\x18programme_resource.proto\x1a\x12terminaltype.proto\"\xce\x01\n\x0fStartRunRequest\x12\x1c\n\tresources\x18\x01 \x03(\x0b\x32\t.Resource\x12#\n\x0cterminalType\x18\x02 \x01(\x0e\x32\r.TerminalType\x12\x18\n\x10programmeVersion\x18\x03 \x01(\x05\x12\x11\n\tclientLan\x18\x04 \x01(\t\x12\x19\n\x11\x63lientVersionName\x18\x05 \x01(\t\x12\x19\n\x11\x63lientVersionCode\x18\x06 \x01(\x05\x12\x15\n\rclientCountry\x18\x07 \x01(\t\"X\n\x10StartRunResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x1d\n\x15robotProgrammeVersion\x18\x03 \x01(\x05\x42\x1f\n\x1d\x63om.ubtechinc.alpha.programmeb\x06proto3'
    ,
    dependencies=[programme__resource__pb2.DESCRIPTOR, terminaltype__pb2.DESCRIPTOR, ])

_STARTRUNREQUEST = _descriptor.Descriptor(
    name='StartRunRequest',
    full_name='StartRunRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='resources', full_name='StartRunRequest.resources', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='terminalType', full_name='StartRunRequest.terminalType', index=1,
            number=2, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='programmeVersion', full_name='StartRunRequest.programmeVersion', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='clientLan', full_name='StartRunRequest.clientLan', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='clientVersionName', full_name='StartRunRequest.clientVersionName', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='clientVersionCode', full_name='StartRunRequest.clientVersionCode', index=5,
            number=6, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='clientCountry', full_name='StartRunRequest.clientCountry', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=75,
    serialized_end=281,
)

_STARTRUNRESPONSE = _descriptor.Descriptor(
    name='StartRunResponse',
    full_name='StartRunResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='StartRunResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='StartRunResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='robotProgrammeVersion', full_name='StartRunResponse.robotProgrammeVersion', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=283,
    serialized_end=371,
)

_STARTRUNREQUEST.fields_by_name['resources'].message_type = programme__resource__pb2._RESOURCE
_STARTRUNREQUEST.fields_by_name['terminalType'].enum_type = terminaltype__pb2._TERMINALTYPE
DESCRIPTOR.message_types_by_name['StartRunRequest'] = _STARTRUNREQUEST
DESCRIPTOR.message_types_by_name['StartRunResponse'] = _STARTRUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StartRunRequest = _reflection.GeneratedProtocolMessageType('StartRunRequest', (_message.Message,), {
    'DESCRIPTOR': _STARTRUNREQUEST,
    '__module__': 'programme_startrun_pb2'
    # @@protoc_insertion_point(class_scope:StartRunRequest)
})
_sym_db.RegisterMessage(StartRunRequest)

StartRunResponse = _reflection.GeneratedProtocolMessageType('StartRunResponse', (_message.Message,), {
    'DESCRIPTOR': _STARTRUNRESPONSE,
    '__module__': 'programme_startrun_pb2'
    # @@protoc_insertion_point(class_scope:StartRunResponse)
})
_sym_db.RegisterMessage(StartRunResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
