# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_InstallWheel.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_InstallWheel.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\030com.ubtechinc.alpha.pypi',
  serialized_pb=b'\n\x17PyPi_InstallWheel.proto\"P\n\x13InstallWheelRequest\x12\x11\n\twheelName\x18\x01 \x01(\t\x12\x17\n\x0fserializePacket\x18\x02 \x01(\x0c\x12\r\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\";\n\x14InstallWheelResponse\x12\x12\n\nresultCode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\tB\x1a\n\x18\x63om.ubtechinc.alpha.pypib\x06proto3'
)




_INSTALLWHEELREQUEST = _descriptor.Descriptor(
  name='InstallWheelRequest',
  full_name='InstallWheelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheelName', full_name='InstallWheelRequest.wheelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serializePacket', full_name='InstallWheelRequest.serializePacket', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug', full_name='InstallWheelRequest.debug', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=107,
)


_INSTALLWHEELRESPONSE = _descriptor.Descriptor(
  name='InstallWheelResponse',
  full_name='InstallWheelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='InstallWheelResponse.resultCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='InstallWheelResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=168,
)

DESCRIPTOR.message_types_by_name['InstallWheelRequest'] = _INSTALLWHEELREQUEST
DESCRIPTOR.message_types_by_name['InstallWheelResponse'] = _INSTALLWHEELRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InstallWheelRequest = _reflection.GeneratedProtocolMessageType('InstallWheelRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLWHEELREQUEST,
  '__module__' : 'PyPi_InstallWheel_pb2'
  # @@protoc_insertion_point(class_scope:InstallWheelRequest)
  })
_sym_db.RegisterMessage(InstallWheelRequest)

InstallWheelResponse = _reflection.GeneratedProtocolMessageType('InstallWheelResponse', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLWHEELRESPONSE,
  '__module__' : 'PyPi_InstallWheel_pb2'
  # @@protoc_insertion_point(class_scope:InstallWheelResponse)
  })
_sym_db.RegisterMessage(InstallWheelResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
