# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getrobotsid.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getrobotsid.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x19\x63odemao_getrobotsid.proto\"\x14\n\x12GetRobotSidRequest\"\'\n\x13GetRobotSidResponse\x12\x10\n\x08robotSid\x18\x01 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_GETROBOTSIDREQUEST = _descriptor.Descriptor(
    name='GetRobotSidRequest',
    full_name='GetRobotSidRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=29,
    serialized_end=49,
)

_GETROBOTSIDRESPONSE = _descriptor.Descriptor(
    name='GetRobotSidResponse',
    full_name='GetRobotSidResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='robotSid', full_name='GetRobotSidResponse.robotSid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=51,
    serialized_end=90,
)

DESCRIPTOR.message_types_by_name['GetRobotSidRequest'] = _GETROBOTSIDREQUEST
DESCRIPTOR.message_types_by_name['GetRobotSidResponse'] = _GETROBOTSIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRobotSidRequest = _reflection.GeneratedProtocolMessageType('GetRobotSidRequest', (_message.Message,), {
    'DESCRIPTOR': _GETROBOTSIDREQUEST,
    '__module__': 'codemao_getrobotsid_pb2'
    # @@protoc_insertion_point(class_scope:GetRobotSidRequest)
})
_sym_db.RegisterMessage(GetRobotSidRequest)

GetRobotSidResponse = _reflection.GeneratedProtocolMessageType('GetRobotSidResponse', (_message.Message,), {
    'DESCRIPTOR': _GETROBOTSIDRESPONSE,
    '__module__': 'codemao_getrobotsid_pb2'
    # @@protoc_insertion_point(class_scope:GetRobotSidResponse)
})
_sym_db.RegisterMessage(GetRobotSidResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
