# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_controlfindface.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_controlfindface.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1d\x63odemao_controlfindface.proto\"7\n\x16\x43ontrolFindFaceRequest\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"]\n\x17\x43ontrolFindFaceResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\x11\n\tfaceCount\x18\x04 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_CONTROLFINDFACEREQUEST = _descriptor.Descriptor(
    name='ControlFindFaceRequest',
    full_name='ControlFindFaceRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='ControlFindFaceRequest.type', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='timeout', full_name='ControlFindFaceRequest.timeout', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=33,
    serialized_end=88,
)

_CONTROLFINDFACERESPONSE = _descriptor.Descriptor(
    name='ControlFindFaceResponse',
    full_name='ControlFindFaceResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='ControlFindFaceResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='code', full_name='ControlFindFaceResponse.code', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='status', full_name='ControlFindFaceResponse.status', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='faceCount', full_name='ControlFindFaceResponse.faceCount', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=90,
    serialized_end=183,
)

DESCRIPTOR.message_types_by_name['ControlFindFaceRequest'] = _CONTROLFINDFACEREQUEST
DESCRIPTOR.message_types_by_name['ControlFindFaceResponse'] = _CONTROLFINDFACERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlFindFaceRequest = _reflection.GeneratedProtocolMessageType('ControlFindFaceRequest', (_message.Message,), {
    'DESCRIPTOR': _CONTROLFINDFACEREQUEST,
    '__module__': 'codemao_controlfindface_pb2'
    # @@protoc_insertion_point(class_scope:ControlFindFaceRequest)
})
_sym_db.RegisterMessage(ControlFindFaceRequest)

ControlFindFaceResponse = _reflection.GeneratedProtocolMessageType('ControlFindFaceResponse', (_message.Message,), {
    'DESCRIPTOR': _CONTROLFINDFACERESPONSE,
    '__module__': 'codemao_controlfindface_pb2'
    # @@protoc_insertion_point(class_scope:ControlFindFaceResponse)
})
_sym_db.RegisterMessage(ControlFindFaceResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
