# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_takepicture.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='pccodemao_takepicture.proto',
  package='packet',
  syntax='proto3',
  serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\022PcTakePictureProto',
  serialized_pb=b'\n\x1bpccodemao_takepicture.proto\x12\x06packet\"2\n\x14PcTakePictureRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\">\n\x15PcTakePictureResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x32\n\x1c\x63om.ubtrobot.pccodemao.protoB\x12PcTakePictureProtob\x06proto3'
)




_PCTAKEPICTUREREQUEST = _descriptor.Descriptor(
  name='PcTakePictureRequest',
  full_name='packet.PcTakePictureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='packet.PcTakePictureRequest.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='packet.PcTakePictureRequest.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=89,
)


_PCTAKEPICTURERESPONSE = _descriptor.Descriptor(
  name='PcTakePictureResponse',
  full_name='packet.PcTakePictureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='packet.PcTakePictureResponse.isSuccess', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='packet.PcTakePictureResponse.resultCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=153,
)

DESCRIPTOR.message_types_by_name['PcTakePictureRequest'] = _PCTAKEPICTUREREQUEST
DESCRIPTOR.message_types_by_name['PcTakePictureResponse'] = _PCTAKEPICTURERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PcTakePictureRequest = _reflection.GeneratedProtocolMessageType('PcTakePictureRequest', (_message.Message,), {
  'DESCRIPTOR' : _PCTAKEPICTUREREQUEST,
  '__module__' : 'pccodemao_takepicture_pb2'
  # @@protoc_insertion_point(class_scope:packet.PcTakePictureRequest)
  })
_sym_db.RegisterMessage(PcTakePictureRequest)

PcTakePictureResponse = _reflection.GeneratedProtocolMessageType('PcTakePictureResponse', (_message.Message,), {
  'DESCRIPTOR' : _PCTAKEPICTURERESPONSE,
  '__module__' : 'pccodemao_takepicture_pb2'
  # @@protoc_insertion_point(class_scope:packet.PcTakePictureResponse)
  })
_sym_db.RegisterMessage(PcTakePictureResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
