# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_message.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..pb2 import pccodemao_messageheader_pb2 as pccodemao__messageheader__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pccodemao_message.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\034com.ubtrobot.pccodemao.proto',
  serialized_pb=b'\n\x17pccodemao_message.proto\x1a\x1dpccodemao_messageheader.proto\";\n\x07Message\x12\x1e\n\x06header\x18\x01 \x01(\x0b\x32\x0e.MessageHeader\x12\x10\n\x08\x62odyData\x18\x02 \x01(\x0c\x42\x1e\n\x1c\x63om.ubtrobot.pccodemao.protob\x06proto3'
  ,
  dependencies=[pccodemao__messageheader__pb2.DESCRIPTOR,])




_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='Message.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyData', full_name='Message.bodyData', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=117,
)

_MESSAGE.fields_by_name['header'].message_type = pccodemao__messageheader__pb2._MESSAGEHEADER
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'pccodemao_message_pb2'
  # @@protoc_insertion_point(class_scope:Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
