# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_wiki.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import cloudwiki_pb2 as cloudwiki__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_wiki.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x12\x63odemao_wiki.proto\x1a\x0f\x63loudwiki.proto\"\"\n\x0bWikiRequest\x12\x13\n\x04wiki\x18\x01 \x01(\x0b\x32\x05.WiKi\"5\n\x0cWikiResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
    ,
    dependencies=[cloudwiki__pb2.DESCRIPTOR, ])

_WIKIREQUEST = _descriptor.Descriptor(
    name='WikiRequest',
    full_name='WikiRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='wiki', full_name='WikiRequest.wiki', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=39,
    serialized_end=73,
)

_WIKIRESPONSE = _descriptor.Descriptor(
    name='WikiResponse',
    full_name='WikiResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='WikiResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='WikiResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=75,
    serialized_end=128,
)

_WIKIREQUEST.fields_by_name['wiki'].message_type = cloudwiki__pb2._WIKI
DESCRIPTOR.message_types_by_name['WikiRequest'] = _WIKIREQUEST
DESCRIPTOR.message_types_by_name['WikiResponse'] = _WIKIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WikiRequest = _reflection.GeneratedProtocolMessageType('WikiRequest', (_message.Message,), {
    'DESCRIPTOR': _WIKIREQUEST,
    '__module__': 'codemao_wiki_pb2'
    # @@protoc_insertion_point(class_scope:WikiRequest)
})
_sym_db.RegisterMessage(WikiRequest)

WikiResponse = _reflection.GeneratedProtocolMessageType('WikiResponse', (_message.Message,), {
    'DESCRIPTOR': _WIKIRESPONSE,
    '__module__': 'codemao_wiki_pb2'
    # @@protoc_insertion_point(class_scope:WikiResponse)
})
_sym_db.RegisterMessage(WikiResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
