# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_facedetecttask.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_facedetecttask.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1c\x63odemao_facedetecttask.proto\"j\n\x15\x46\x61\x63\x65\x44\x65tectTaskRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\x12\x0e\n\x06period\x18\x02 \x01(\x05\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\x12\x0e\n\x06switch\x18\x04 \x01(\x08\x12\x11\n\tcommandId\x18\x05 \x01(\t\"a\n\x16\x46\x61\x63\x65\x44\x65tectTaskResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x12\x11\n\tcommandId\x18\x04 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_FACEDETECTTASKREQUEST = _descriptor.Descriptor(
    name='FaceDetectTaskRequest',
    full_name='FaceDetectTaskRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceDetectTaskRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='period', full_name='FaceDetectTaskRequest.period', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='delay', full_name='FaceDetectTaskRequest.delay', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='switch', full_name='FaceDetectTaskRequest.switch', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceDetectTaskRequest.commandId', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=32,
    serialized_end=138,
)

_FACEDETECTTASKRESPONSE = _descriptor.Descriptor(
    name='FaceDetectTaskResponse',
    full_name='FaceDetectTaskResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='count', full_name='FaceDetectTaskResponse.count', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceDetectTaskResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceDetectTaskResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceDetectTaskResponse.commandId', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=140,
    serialized_end=237,
)

DESCRIPTOR.message_types_by_name['FaceDetectTaskRequest'] = _FACEDETECTTASKREQUEST
DESCRIPTOR.message_types_by_name['FaceDetectTaskResponse'] = _FACEDETECTTASKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceDetectTaskRequest = _reflection.GeneratedProtocolMessageType('FaceDetectTaskRequest', (_message.Message,), {
    'DESCRIPTOR': _FACEDETECTTASKREQUEST,
    '__module__': 'codemao_facedetecttask_pb2'
    # @@protoc_insertion_point(class_scope:FaceDetectTaskRequest)
})
_sym_db.RegisterMessage(FaceDetectTaskRequest)

FaceDetectTaskResponse = _reflection.GeneratedProtocolMessageType('FaceDetectTaskResponse', (_message.Message,), {
    'DESCRIPTOR': _FACEDETECTTASKRESPONSE,
    '__module__': 'codemao_facedetecttask_pb2'
    # @@protoc_insertion_point(class_scope:FaceDetectTaskResponse)
})
_sym_db.RegisterMessage(FaceDetectTaskResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
