# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cmprivacymode.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='cmprivacymode.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x13\x63mprivacymode.proto\"6\n\x14\x43mPrivacyModeRequest\x12\x1e\n\x04type\x18\x01 \x01(\x0e\x32\x10.PrivacyModeType\"7\n\x15\x43mPrivacyModeResponse\x12\x1e\n\x04type\x18\x01 \x01(\x0e\x32\x10.PrivacyModeType*:\n\x0fPrivacyModeType\x12\x13\n\x0fPRIVACYMODE_OFF\x10\x00\x12\x12\n\x0ePRIVACYMODE_ON\x10\x01\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
)

_PRIVACYMODETYPE = _descriptor.EnumDescriptor(
    name='PrivacyModeType',
    full_name='PrivacyModeType',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='PRIVACYMODE_OFF', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='PRIVACYMODE_ON', index=1, number=1,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=136,
    serialized_end=194,
)
_sym_db.RegisterEnumDescriptor(_PRIVACYMODETYPE)

PrivacyModeType = enum_type_wrapper.EnumTypeWrapper(_PRIVACYMODETYPE)
PRIVACYMODE_OFF = 0
PRIVACYMODE_ON = 1

_CMPRIVACYMODEREQUEST = _descriptor.Descriptor(
    name='CmPrivacyModeRequest',
    full_name='CmPrivacyModeRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='CmPrivacyModeRequest.type', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=23,
    serialized_end=77,
)

_CMPRIVACYMODERESPONSE = _descriptor.Descriptor(
    name='CmPrivacyModeResponse',
    full_name='CmPrivacyModeResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='CmPrivacyModeResponse.type', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=79,
    serialized_end=134,
)

_CMPRIVACYMODEREQUEST.fields_by_name['type'].enum_type = _PRIVACYMODETYPE
_CMPRIVACYMODERESPONSE.fields_by_name['type'].enum_type = _PRIVACYMODETYPE
DESCRIPTOR.message_types_by_name['CmPrivacyModeRequest'] = _CMPRIVACYMODEREQUEST
DESCRIPTOR.message_types_by_name['CmPrivacyModeResponse'] = _CMPRIVACYMODERESPONSE
DESCRIPTOR.enum_types_by_name['PrivacyModeType'] = _PRIVACYMODETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CmPrivacyModeRequest = _reflection.GeneratedProtocolMessageType('CmPrivacyModeRequest', (_message.Message,), {
    'DESCRIPTOR': _CMPRIVACYMODEREQUEST,
    '__module__': 'cmprivacymode_pb2'
    # @@protoc_insertion_point(class_scope:CmPrivacyModeRequest)
})
_sym_db.RegisterMessage(CmPrivacyModeRequest)

CmPrivacyModeResponse = _reflection.GeneratedProtocolMessageType('CmPrivacyModeResponse', (_message.Message,), {
    'DESCRIPTOR': _CMPRIVACYMODERESPONSE,
    '__module__': 'cmprivacymode_pb2'
    # @@protoc_insertion_point(class_scope:CmPrivacyModeResponse)
})
_sym_db.RegisterMessage(CmPrivacyModeResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
