# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_messageheader.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='pccodemao_messageheader.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\022MessageHeaderProto',
  serialized_pb=b'\n\x1dpccodemao_messageheader.proto\"<\n\rMessageHeader\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x42\x32\n\x1c\x63om.ubtrobot.pccodemao.protoB\x12MessageHeaderProtob\x06proto3'
)




_MESSAGEHEADER = _descriptor.Descriptor(
  name='MessageHeader',
  full_name='MessageHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='MessageHeader.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='MessageHeader.target', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='MessageHeader.command', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=93,
)

DESCRIPTOR.message_types_by_name['MessageHeader'] = _MESSAGEHEADER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MessageHeader = _reflection.GeneratedProtocolMessageType('MessageHeader', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEHEADER,
  '__module__' : 'pccodemao_messageheader_pb2'
  # @@protoc_insertion_point(class_scope:MessageHeader)
  })
_sym_db.RegisterMessage(MessageHeader)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
