# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_faceanalyze.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_faceinfo_pb2 as codemao__faceinfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_faceanalyze.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x19\x63odemao_faceanalyze.proto\x1a\x16\x63odemao_faceinfo.proto\"%\n\x12\x46\x61\x63\x65\x41nalyzeRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\"b\n\x13\x46\x61\x63\x65\x41nalyzeResponse\x12$\n\tfaceInfos\x18\x01 \x03(\x0b\x32\x11.FaceInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
    ,
    dependencies=[codemao__faceinfo__pb2.DESCRIPTOR, ])

_FACEANALYZEREQUEST = _descriptor.Descriptor(
    name='FaceAnalyzeRequest',
    full_name='FaceAnalyzeRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceAnalyzeRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=53,
    serialized_end=90,
)

_FACEANALYZERESPONSE = _descriptor.Descriptor(
    name='FaceAnalyzeResponse',
    full_name='FaceAnalyzeResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='faceInfos', full_name='FaceAnalyzeResponse.faceInfos', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceAnalyzeResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceAnalyzeResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=92,
    serialized_end=190,
)

_FACEANALYZERESPONSE.fields_by_name['faceInfos'].message_type = codemao__faceinfo__pb2._FACEINFORESPONSE
DESCRIPTOR.message_types_by_name['FaceAnalyzeRequest'] = _FACEANALYZEREQUEST
DESCRIPTOR.message_types_by_name['FaceAnalyzeResponse'] = _FACEANALYZERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceAnalyzeRequest = _reflection.GeneratedProtocolMessageType('FaceAnalyzeRequest', (_message.Message,), {
    'DESCRIPTOR': _FACEANALYZEREQUEST,
    '__module__': 'codemao_faceanalyze_pb2'
    # @@protoc_insertion_point(class_scope:FaceAnalyzeRequest)
})
_sym_db.RegisterMessage(FaceAnalyzeRequest)

FaceAnalyzeResponse = _reflection.GeneratedProtocolMessageType('FaceAnalyzeResponse', (_message.Message,), {
    'DESCRIPTOR': _FACEANALYZERESPONSE,
    '__module__': 'codemao_faceanalyze_pb2'
    # @@protoc_insertion_point(class_scope:FaceAnalyzeResponse)
})
_sym_db.RegisterMessage(FaceAnalyzeResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
