# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getinfrareddistance.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getinfrareddistance.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n!codemao_getinfrareddistance.proto\"\x1c\n\x1aGetInfraredDistanceRequest\"/\n\x1bGetInfraredDistanceResponse\x12\x10\n\x08\x64istance\x18\x01 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_GETINFRAREDDISTANCEREQUEST = _descriptor.Descriptor(
    name='GetInfraredDistanceRequest',
    full_name='GetInfraredDistanceRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=37,
    serialized_end=65,
)

_GETINFRAREDDISTANCERESPONSE = _descriptor.Descriptor(
    name='GetInfraredDistanceResponse',
    full_name='GetInfraredDistanceResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='distance', full_name='GetInfraredDistanceResponse.distance', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=67,
    serialized_end=114,
)

DESCRIPTOR.message_types_by_name['GetInfraredDistanceRequest'] = _GETINFRAREDDISTANCEREQUEST
DESCRIPTOR.message_types_by_name['GetInfraredDistanceResponse'] = _GETINFRAREDDISTANCERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetInfraredDistanceRequest = _reflection.GeneratedProtocolMessageType('GetInfraredDistanceRequest', (_message.Message,),
                                                                      {
                                                                          'DESCRIPTOR': _GETINFRAREDDISTANCEREQUEST,
                                                                          '__module__': 'codemao_getinfrareddistance_pb2'
                                                                          # @@protoc_insertion_point(class_scope:GetInfraredDistanceRequest)
                                                                      })
_sym_db.RegisterMessage(GetInfraredDistanceRequest)

GetInfraredDistanceResponse = _reflection.GeneratedProtocolMessageType('GetInfraredDistanceResponse',
                                                                       (_message.Message,), {
                                                                           'DESCRIPTOR': _GETINFRAREDDISTANCERESPONSE,
                                                                           '__module__': 'codemao_getinfrareddistance_pb2'
                                                                           # @@protoc_insertion_point(class_scope:GetInfraredDistanceResponse)
                                                                       })
_sym_db.RegisterMessage(GetInfraredDistanceResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
