# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getactionlist.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_actioninfo_pb2 as codemao__actioninfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getactionlist.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1b\x63odemao_getactionlist.proto\x1a\x18\x63odemao_actioninfo.proto\"@\n\x14GetActionListRequest\x12\x14\n\x0clanguageType\x18\x01 \x01(\t\x12\x12\n\nactionType\x18\x02 \x01(\x05\"g\n\x15GetActionListResponse\x12\'\n\nactionList\x18\x01 \x03(\x0b\x32\x13.ActionInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
    ,
    dependencies=[codemao__actioninfo__pb2.DESCRIPTOR, ])

_GETACTIONLISTREQUEST = _descriptor.Descriptor(
    name='GetActionListRequest',
    full_name='GetActionListRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='languageType', full_name='GetActionListRequest.languageType', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='actionType', full_name='GetActionListRequest.actionType', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=57,
    serialized_end=121,
)

_GETACTIONLISTRESPONSE = _descriptor.Descriptor(
    name='GetActionListResponse',
    full_name='GetActionListResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='actionList', full_name='GetActionListResponse.actionList', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='GetActionListResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='GetActionListResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=123,
    serialized_end=226,
)

_GETACTIONLISTRESPONSE.fields_by_name['actionList'].message_type = codemao__actioninfo__pb2._ACTIONINFORESPONSE
DESCRIPTOR.message_types_by_name['GetActionListRequest'] = _GETACTIONLISTREQUEST
DESCRIPTOR.message_types_by_name['GetActionListResponse'] = _GETACTIONLISTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetActionListRequest = _reflection.GeneratedProtocolMessageType('GetActionListRequest', (_message.Message,), {
    'DESCRIPTOR': _GETACTIONLISTREQUEST,
    '__module__': 'codemao_getactionlist_pb2'
    # @@protoc_insertion_point(class_scope:GetActionListRequest)
})
_sym_db.RegisterMessage(GetActionListRequest)

GetActionListResponse = _reflection.GeneratedProtocolMessageType('GetActionListResponse', (_message.Message,), {
    'DESCRIPTOR': _GETACTIONLISTRESPONSE,
    '__module__': 'codemao_getactionlist_pb2'
    # @@protoc_insertion_point(class_scope:GetActionListResponse)
})
_sym_db.RegisterMessage(GetActionListResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
