# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_GetWheelList.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_GetWheelList.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\030com.ubtechinc.alpha.pypi',
  serialized_pb=b'\n\x17PyPi_GetWheelList.proto\"\x15\n\x13GetWheelListRequest\"I\n\x14GetWheelListResponse\x12\x12\n\nresultCode\x18\x01 \x01(\x05\x12\x0e\n\x06Wheels\x18\x02 \x03(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\tB\x1a\n\x18\x63om.ubtechinc.alpha.pypib\x06proto3'
)




_GETWHEELLISTREQUEST = _descriptor.Descriptor(
  name='GetWheelListRequest',
  full_name='GetWheelListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=48,
)


_GETWHEELLISTRESPONSE = _descriptor.Descriptor(
  name='GetWheelListResponse',
  full_name='GetWheelListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='GetWheelListResponse.resultCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Wheels', full_name='GetWheelListResponse.Wheels', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='GetWheelListResponse.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=123,
)

DESCRIPTOR.message_types_by_name['GetWheelListRequest'] = _GETWHEELLISTREQUEST
DESCRIPTOR.message_types_by_name['GetWheelListResponse'] = _GETWHEELLISTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetWheelListRequest = _reflection.GeneratedProtocolMessageType('GetWheelListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWHEELLISTREQUEST,
  '__module__' : 'PyPi_GetWheelList_pb2'
  # @@protoc_insertion_point(class_scope:GetWheelListRequest)
  })
_sym_db.RegisterMessage(GetWheelListRequest)

GetWheelListResponse = _reflection.GeneratedProtocolMessageType('GetWheelListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWHEELLISTRESPONSE,
  '__module__' : 'PyPi_GetWheelList_pb2'
  # @@protoc_insertion_point(class_scope:GetWheelListResponse)
  })
_sym_db.RegisterMessage(GetWheelListResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
